#
the 'organelle_config' path contains a workflow definitions and the _contracts_ for the workflow module to access the infer_subc module.

all_functions.json contains prototypes for all the functions callable by workflows.

